.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _basics:

canary basics
=============

This section covers every basic command you need to get started with Canary.  By the end of the section, you should be able to create a Canary workspace, add test files to it, run the tests, inspect results, and create reports.

.. toctree::
   :maxdepth: 1

   basics.workspace
   basics.testfile
   basics.testcase
   basics.status
   basics.resource
   basics.runtime
